@@ -110,7 +110,11 @@ class DefaultRequirements(SuiteRequirements):
         return only_on(['oracle'])
 
     @property
-    def foreign_key_constraint_option_reflection(self):
+    def foreign_key_constraint_option_reflection_ondelete(self):
+        return only_on(['postgresql', 'mysql', 'sqlite', 'oracle'])
+
+    @property
+    def foreign_key_constraint_option_reflection_onupdate(self):
         return only_on(['postgresql', 'mysql', 'sqlite'])
 
     @property
@@ -136,6 +140,22 @@ class DefaultRequirements(SuiteRequirements):
             no_support('sybase', 'not supported by database'),
         ])
 
+    @property
+    def non_native_boolean_unconstrained(self):
+        """target database is not native boolean and allows arbitrary integers
+        in it's "bool" column"""
+
+        return skip_if([
+            LambdaPredicate(
+                lambda config: against(config, "mssql"),
+                "SQL Server drivers / odbc seem to change their mind on this"
+            ),
+            LambdaPredicate(
+                lambda config: config.db.dialect.supports_native_boolean,
+                "native boolean dialect"
+            )
+        ])
+
     @property
     def standalone_binds(self):
         """target database/driver supports bound parameters as column expressions
@@ -309,6 +329,14 @@ class DefaultRequirements(SuiteRequirements):
                        'PG triggers need to be implemented for tests'),
         ])
 
+    @property
+    def sequences_as_server_defaults(self):
+        """Target database must support SEQUENCE as a server side default."""
+
+        return only_on(
+            'postgresql',
+            "doesn't support sequences as a server side default.")
+
     @property
     def correlated_outer_joins(self):
         """Target must support an outer join to a subquery which
@@ -328,7 +356,7 @@ class DefaultRequirements(SuiteRequirements):
     def delete_from(self):
         """Target must support DELETE FROM..FROM or DELETE..USING syntax"""
         return only_on(['postgresql', 'mssql', 'mysql', 'sybase'],
-                       "Backend does not support UPDATE..FROM")
+                       "Backend does not support DELETE..FROM")
 
     @property
     def update_where_target_in_subquery(self):
@@ -379,9 +407,24 @@ class DefaultRequirements(SuiteRequirements):
         """target system must support reflection of inter-schema foreign keys
         """
         return only_on([
-                    "postgresql"
+                    "postgresql",
+                    "mysql",
+                    "mssql",
                 ])
 
+    @property
+    def implicit_default_schema(self):
+        """target system has a strong concept of 'default' schema that can
+           be referred to implicitly.
+
+           basically, Postgresql.
+
+        """
+        return only_on([
+                    "postgresql",
+                ])
+
+
     @property
     def unique_constraint_reflection(self):
         return fails_on_everything_except(
@@ -431,14 +474,34 @@ class DefaultRequirements(SuiteRequirements):
     def ctes(self):
         """Target database supports CTEs"""
 
-        return only_if(
-            ['postgresql', 'mssql']
-        )
+        return only_on([
+            lambda config: against(config, "mysql") and (
+                config.db.dialect._is_mariadb and
+                config.db.dialect._mariadb_normalized_version_info >=
+                (10, 2)
+            ),
+            "postgresql",
+            "mssql",
+            "oracle"
+        ])
+
+    @property
+    def ctes_with_update_delete(self):
+        """target database supports CTES that ride on top of a normal UPDATE
+        or DELETE statement which refers to the CTE in a correlated subquery.
+
+        """
+        return only_on([
+            "postgresql",
+            "mssql",
+            # "oracle" - oracle can do this but SQLAlchemy doesn't support
+            # their syntax yet
+        ])
 
     @property
     def ctes_on_dml(self):
         """target database supports CTES which consist of INSERT, UPDATE
-        or DELETE"""
+        or DELETE *within* the CTE, e.g. WITH x AS (UPDATE....)"""
 
         return only_if(
             ['postgresql']
@@ -978,7 +1041,9 @@ class DefaultRequirements(SuiteRequirements):
             # will raise without quoting
             "postgresql": "POSIX",
 
-            "mysql": "latin1_general_ci",
+            # note MySQL databases need to be created w/ utf8mb3 charset
+            # for the test suite
+            "mysql": "utf8mb3_bin",
             "sqlite": "NOCASE",
 
             # will raise *with* quoting
@@ -1002,18 +1067,37 @@ class DefaultRequirements(SuiteRequirements):
 
     @property
     def ad_hoc_engines(self):
-        return exclusions.skip_if(["oracle"])
+        return exclusions.skip_if(
+            ["oracle"],
+            "works, but Oracle just gets tired with "
+            "this much connection activity")
+
+
 
     @property
     def no_mssql_freetds(self):
         return self.mssql_freetds.not_()
 
+    @property
+    def python_fixed_issue_8743(self):
+        return exclusions.skip_if(
+            lambda: sys.version_info < (2, 7, 8),
+            "Python issue 8743 fixed in Python 2.7.8"
+        )
+
     @property
     def selectone(self):
         """target driver must support the literal statement 'select 1'"""
         return skip_if(["oracle", "firebird"],
                        "non-standard SELECT scalar syntax")
 
+    @property
+    def mysql_for_update(self):
+        return skip_if(
+            "mysql+mysqlconnector",
+           "lock-sensitive operations crash on mysqlconnector"
+        )
+
     @property
     def mysql_fsp(self):
         return only_if('mysql >= 5.6.4')
