@@ -278,6 +278,31 @@ class InsertTest(_InsertTestBase, fixtures.TablesTest, AssertsCompiledSQL):
             checkparams={"name_1": "bar"}
         )
 
+    def test_insert_from_select_cte_follows_insert_one(self):
+        dialect = default.DefaultDialect()
+        dialect.cte_follows_insert = True
+
+        table1 = self.tables.mytable
+
+        cte = select([table1.c.name]).where(table1.c.name == 'bar').cte()
+
+        sel = select([table1.c.myid, table1.c.name]).where(
+            table1.c.name == cte.c.name)
+
+        ins = self.tables.myothertable.insert().\
+            from_select(("otherid", "othername"), sel)
+        self.assert_compile(
+            ins,
+            "INSERT INTO myothertable (otherid, othername) "
+            "WITH anon_1 AS "
+            "(SELECT mytable.name AS name FROM mytable "
+            "WHERE mytable.name = :name_1) "
+            "SELECT mytable.myid, mytable.name FROM mytable, anon_1 "
+            "WHERE mytable.name = anon_1.name",
+            checkparams={"name_1": "bar"},
+            dialect=dialect
+        )
+
     def test_insert_from_select_cte_two(self):
         table1 = self.tables.mytable
 
@@ -293,6 +318,24 @@ class InsertTest(_InsertTestBase, fixtures.TablesTest, AssertsCompiledSQL):
             "SELECT c.myid, c.name, c.description FROM c"
         )
 
+    def test_insert_from_select_cte_follows_insert_two(self):
+        dialect = default.DefaultDialect()
+        dialect.cte_follows_insert = True
+        table1 = self.tables.mytable
+
+        cte = table1.select().cte("c")
+        stmt = cte.select()
+        ins = table1.insert().from_select(table1.c, stmt)
+
+        self.assert_compile(
+            ins,
+            "INSERT INTO mytable (myid, name, description) "
+            "WITH c AS (SELECT mytable.myid AS myid, mytable.name AS name, "
+            "mytable.description AS description FROM mytable) "
+            "SELECT c.myid, c.name, c.description FROM c",
+            dialect=dialect
+        )
+
     def test_insert_from_select_select_alt_ordering(self):
         table1 = self.tables.mytable
         sel = select([table1.c.name, table1.c.myid]).where(
@@ -839,6 +882,39 @@ class MultirowTest(_InsertTestBase, fixtures.TablesTest, AssertsCompiledSQL):
             checkparams=checkparams,
             dialect=dialect)
 
+    def test_named_with_column_objects(self):
+        table1 = self.tables.mytable
+
+        values = [
+            {table1.c.myid: 1, table1.c.name: 'a', table1.c.description: 'b'},
+            {table1.c.myid: 2, table1.c.name: 'c', table1.c.description: 'd'},
+            {table1.c.myid: 3, table1.c.name: 'e', table1.c.description: 'f'},
+        ]
+
+        checkparams = {
+            'myid_m0': 1,
+            'myid_m1': 2,
+            'myid_m2': 3,
+            'name_m0': 'a',
+            'name_m1': 'c',
+            'name_m2': 'e',
+            'description_m0': 'b',
+            'description_m1': 'd',
+            'description_m2': 'f',
+        }
+
+        dialect = default.DefaultDialect()
+        dialect.supports_multivalues_insert = True
+
+        self.assert_compile(
+            table1.insert().values(values),
+            'INSERT INTO mytable (myid, name, description) VALUES '
+            '(:myid_m0, :name_m0, :description_m0), '
+            '(:myid_m1, :name_m1, :description_m1), '
+            '(:myid_m2, :name_m2, :description_m2)',
+            checkparams=checkparams,
+            dialect=dialect)
+
     def test_positional(self):
         table1 = self.tables.mytable
 
