@@ -51,7 +51,7 @@ class _UpdateFromTestBase(object):
                 (9, 'fred'),
                 (10, 'chuck')
             ),
-            addresses = (
+            addresses=(
                 ('id', 'user_id', 'name', 'email_address'),
                 (1, 7, 'x', 'jack@bean.com'),
                 (2, 8, 'x', 'ed@wood.com'),
@@ -59,7 +59,7 @@ class _UpdateFromTestBase(object):
                 (4, 8, 'x', 'ed@lala.com'),
                 (5, 9, 'x', 'fred@fred.com')
             ),
-            dingalings = (
+            dingalings=(
                 ('id', 'address_id', 'data'),
                 (1, 2, 'ding 1/2'),
                 (2, 5, 'ding 2/5')
@@ -306,8 +306,8 @@ class UpdateTest(_UpdateFromTestBase, fixtures.TablesTest, AssertsCompiledSQL):
         table1 = self.tables.mytable
         testing.assert_raises_message(
             ValueError,
-            "When preserve_parameter_order is True, values\(\) "
-            "only accepts a list of 2-tuples",
+            r"When preserve_parameter_order is True, values\(\) "
+            r"only accepts a list of 2-tuples",
             table1.update(preserve_parameter_order=True).values,
             {"description": "foo", "name": "bar"}
         )
@@ -340,13 +340,14 @@ class UpdateTest(_UpdateFromTestBase, fixtures.TablesTest, AssertsCompiledSQL):
     def test_where_empty(self):
         table1 = self.tables.mytable
         self.assert_compile(
-            table1.update().where(
-                and_()),
-            "UPDATE mytable SET myid=:myid, name=:name, description=:description")
+            table1.update().where(and_()),
+            "UPDATE mytable SET myid=:myid, name=:name, "
+            "description=:description")
         self.assert_compile(
             table1.update().where(
                 or_()),
-            "UPDATE mytable SET myid=:myid, name=:name, description=:description")
+            "UPDATE mytable SET myid=:myid, name=:name, "
+            "description=:description")
 
     def test_prefix_with(self):
         table1 = self.tables.mytable
@@ -390,7 +391,7 @@ class UpdateTest(_UpdateFromTestBase, fixtures.TablesTest, AssertsCompiledSQL):
             where(table1.c.name == sel.c.othername).\
             values(name='foo')
 
-        dialect = default.DefaultDialect()
+        dialect = default.StrCompileDialect()
         dialect.positional = True
         self.assert_compile(
             upd,
@@ -418,7 +419,7 @@ class UpdateTest(_UpdateFromTestBase, fixtures.TablesTest, AssertsCompiledSQL):
 
 class UpdateFromCompileTest(_UpdateFromTestBase, fixtures.TablesTest,
                             AssertsCompiledSQL):
-    __dialect__ = 'default'
+    __dialect__ = 'default_enhanced'
 
     run_create_tables = run_inserts = run_deletes = None
 
@@ -480,6 +481,23 @@ class UpdateFromCompileTest(_UpdateFromTestBase, fixtures.TablesTest,
             dialect='mysql'
         )
 
+    def test_update_from_join_mysql(self):
+        users, addresses = self.tables.users, self.tables.addresses
+
+        j = users.join(addresses)
+        self.assert_compile(
+            update(j).
+            values(name='newname').
+            where(addresses.c.email_address == 'e1'),
+            ""
+            'UPDATE users '
+            'INNER JOIN addresses ON users.id = addresses.user_id '
+            'SET users.name=%s '
+            'WHERE '
+            'addresses.email_address = %s',
+            checkparams={'email_address_1': 'e1', 'name': 'newname'},
+            dialect=mysql.dialect())
+
     def test_render_table(self):
         users, addresses = self.tables.users, self.tables.addresses
 
@@ -668,6 +686,35 @@ class UpdateFromRoundTripTest(_UpdateFromTestBase, fixtures.TablesTest):
             (10, 'chuck')]
         self._assert_users(users, expected)
 
+    @testing.only_on('mysql', 'Multi table update')
+    def test_exec_join_multitable(self):
+        users, addresses = self.tables.users, self.tables.addresses
+
+        values = {
+            addresses.c.email_address: 'updated',
+            users.c.name: 'ed2'
+        }
+
+        testing.db.execute(
+            update(users.join(addresses)).
+            values(values).
+            where(users.c.name == 'ed'))
+
+        expected = [
+            (1, 7, 'x', 'jack@bean.com'),
+            (2, 8, 'x', 'updated'),
+            (3, 8, 'x', 'updated'),
+            (4, 8, 'x', 'updated'),
+            (5, 9, 'x', 'fred@fred.com')]
+        self._assert_addresses(addresses, expected)
+
+        expected = [
+            (7, 'jack'),
+            (8, 'ed2'),
+            (9, 'fred'),
+            (10, 'chuck')]
+        self._assert_users(users, expected)
+
     @testing.only_on('mysql', 'Multi table update')
     def test_exec_multitable_same_name(self):
         users, addresses = self.tables.users, self.tables.addresses
